<?php
/*
Plugin Name: Basic Google Analytics
Plugin URI: http://mjkjr.com/products/basic-google-analytics/
Description: Add the Google Analytics tracking code to your Wordpress site.
Author: Michael John Kozubal Jr.
Version: 0.1
Author URI: http://mjkjr.com/
License: MIT License
License URI: http://opensource.org/licenses/MIT

Copyright (c) 2013 Michael John Kozubal Jr. <michael@mjkjr.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

namespace mjkjr_bga;

define('I18N', 'basic-google-analytics');
define('SLUG', 'basic-google-analytics');
define('VERSION', '0.1');
define('VER_KEY', 'mjkjr_bga_version');
define('OPTIONS', 'mjkjr_bga_options');


/**
 *	Load translations
 */
function init()
{
	\load_plugin_textdomain(I18N, false, \basename(dirname(__FILE__)));
}
\add_action('plugins_loaded', '\mjkjr_bga\init');

/**
 *	Add a link to the settings on the plugin page
 */
function settings_plugin_link($links, $file)
{
    if ($file == \plugin_basename(__FILE__))
	{
        $link = '<a href="options-general.php?page=' . SLUG . '">' . __('Settings', I18N) . '</a>';
        array_unshift($links, $link);
    }
    return $links;
}
\add_filter('plugin_action_links', '\mjkjr_bga\settings_plugin_link', 10, 2);


/**
 *	Register default settings (use existing settings if possible)
 */
function register_default_settings()
{

	if (\add_option(VER_KEY, VERSION) === FALSE)
	{
		$installed_version = \get_option(VER_KEY);

		if ($installed_version != VERSION)
		{
			// do upgrade here

			\update_option(VER_KEY, VERSION);
		}
	}

	$defaults = array('ga_property_id' => '', 'ga_site_verification' => '');
	\add_option(OPTIONS, $defaults);
}
\register_activation_hook(__FILE__, '\mjkjr_bga\register_default_settings');

/**
 *	Create settings page, sections, and fields
 */
function admin_menu()
{
	\add_submenu_page('options-general.php', \__('Basic Google Analytics', I18N), __('Google Analytics', I18N), 'manage_options', SLUG, '\mjkjr_bga\mjkjr_options_page');
	\register_setting(SLUG, OPTIONS, '\mjkjr_bga\options_validate');
	\add_settings_section('mjkjr_bga_settings', \__('Account Settings', I18N), NULL, SLUG);
	\add_settings_field('ga_property_id', \__('Property ID', I18N), '\mjkjr_bga\ga_property_id_field', SLUG, 'mjkjr_bga_settings');
	\add_settings_field('ga_site_verification', __('Site Meta Verification Code', I18N), '\mjkjr_bga\ga_site_verification_field', SLUG, 'mjkjr_bga_settings');
	\add_settings_section('mjkjr_bga_delete', \__('Delete Plugin Settings', I18N), NULL, SLUG);
	\add_settings_field('ga_delete_data', \__('Delete Settings from Database?', I18N), '\mjkjr_bga\ga_delete_data_field', SLUG, 'mjkjr_bga_delete');
}
\add_action('admin_menu', '\mjkjr_bga\admin_menu');

/**
 *	Display settings page
 */
function mjkjr_options_page()
{
	echo '<div class="wrap">';
	echo 	'<div id="icon-options-general" class="icon32"><br></div>';
	echo 	'<h2>' . __('Basic Google Analytics Settings', I18N) . '</h2>';
	echo 	'<form action="options.php" method="post">';
				\settings_fields(SLUG);
				\do_settings_sections(SLUG);
	echo 		'<p class="sumbit"><input id="sumbit"  class="button button-primary" type="submit" value="' . \esc_attr(\__('Save Changes', I18N)) . '" name="Submit" /></p>';
	echo 	'</form>';
	echo '</div>';
}

/**
 *	Display settings fields
 */
function ga_property_id_field()
{
	$options = \get_option(OPTIONS);
	echo '<input id="ga_property_id" name="' . OPTIONS . '[ga_property_id]" size="20" type="text" value="' . \esc_attr($options['ga_property_id']) . '" placeholder="UA-00000000-0"/>';
	echo '<p class="description">' . \sprintf(\__('Found in the Admin panel of your %1$sGoogle Analytics Account%2$s.', I18N), '<a href="http://www.google.com/analytics/" target="_blank">', '</a>') . '</p>';
}

function ga_site_verification_field()
{
	$options = \get_option(OPTIONS);
	echo '<input id="ga_site_verification" name="' . OPTIONS . '[ga_site_verification]" size="60" type="text" value="' . \esc_attr($options['ga_site_verification']) . '" placeholder="ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+=-" />';
}

function ga_delete_data_field()
{
	echo '<fieldset>';
		echo '<legend class="screen-reader-text"><span>' . \__('Confirm Delete', I18N) . '</span></legend>';
		echo '<label for="ga_confirm_delete"><input id="ga_confirm_delete" name="' . OPTIONS . '[ga_confirm_delete]" type="checkbox" value="true"> ' . \__('Confirm Delete', I18N) . '</label>';
		echo '<p class="description">' . \__("Use this if not uninstalling this plugin from the Wordpress Plugins page.", I18N) . '</p>';
	echo '</fieldset>';
}

/**
 *	Validate settings input
 */
function options_validate($input)
{
	if (isset($input['ga_confirm_delete']) && $input['ga_confirm_delete'] == 'true')
	{
		if (\delete_option(OPTIONS) == TRUE && \delete_option(VER_KEY) === TRUE)
		{
			\add_settings_error('', 'mjkjr_bga_notice', \__('Settings deleted from database!', I18N), 'updated');
		}
		else
		{
			\add_settings_error('ga_confirm_delete', 'mjkjr_bga_error', \__('Unable to delete all settings from database!', I18N), 'error');
		}

		return NULL;
	}

	$valid = array();

	$valid['ga_property_id'] = \sanitize_text_field($input['ga_property_id']);
	if ($valid['ga_property_id'] != $input['ga_property_id'] ) { \add_settings_error('ga_property_id', 'mjkjr_bga_error', \__('Invalid Property ID!', I18N), 'error'); }

	$valid['ga_site_verification'] = \sanitize_text_field($input['ga_site_verification']);
	if ($valid['ga_site_verification'] != $input['ga_site_verification'] ) { \add_settings_error('ga_site_verification', 'mjkjr_bga_error', \__('Invalid Meta Verification ID!', I18N), 'error'); }

	return $valid;
}

/**
 *	Output the Google meta verification tag and analytics tracking codes
 */
function output_tracking_code()
{
	$options = \get_option(OPTIONS);

	if (!empty($options['ga_site_verification']) && \is_front_page()) { echo '<meta name="google-site-verification" content="' . \esc_attr($options['ga_site_verification']) . '" />' . PHP_EOL; }

	if (empty($options['ga_property_id'])) { return; }

	if (!\is_admin() && !\current_user_can('manage_options'))
	{ ?>
		<script type="text/javascript">//<![CDATA[
			var _gaq = _gaq || [];
			_gaq.push(['_setAccount','<?php \esc_attr_e($options['ga_property_id']); ?>']);
			_gaq.push(['_trackPageview'],['_trackPageLoadTime']);
			(function() {
				var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
				ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
				var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
			})();
		//]]></script>
<?php }
}
\add_action('wp_head', '\mjkjr_bga\output_tracking_code');
?>
